BoundUserSession

Struct BoundUserSession 

pub struct BoundUserSession { /* private fields */ }
User session token bound to the authorised session certificate.

Implementations

Source

impl BoundUserSession

pub fn new( session_token: impl Into<String>, identity: &AuthenticatedIdentity, binding: DeviceSessionBinding, created_at: OffsetDateTime, expires_at: OffsetDateTime, ) -> Self

Creates a bound user session.

pub fn session_token(&self) -> &str

Returns the opaque user session token.

pub fn actor_id(&self) -> &ActorId

Returns the authenticated actor.

pub fn tenant_id(&self) -> Option<&TenantId>

Returns the authenticated tenant, if present.

pub fn roles(&self) -> &[String]

Returns the roles copied into this session.

pub fn device_binding(&self) -> &DeviceSessionBinding

Returns the device-session binding.

pub fn created_at(&self) -> OffsetDateTime

Returns the session creation time.

pub fn expires_at(&self) -> OffsetDateTime

Returns the session expiry time.

pub fn is_bound_to(&self, mtls: &MtlsClientIdentity) -> bool

Returns true when this session is presented with its original mTLS certificate.