PasswordlessChallenge

Struct PasswordlessChallenge 

pub struct PasswordlessChallenge { /* private fields */ }
Passwordless challenge issued after device trust and session mTLS checks.

Implementations

Source

impl PasswordlessChallenge

pub fn new( challenge_id: impl Into<String>, method: PasswordlessMethod, binding: DeviceSessionBinding, issued_at: OffsetDateTime, expires_at: OffsetDateTime, ) -> Self

Creates a passwordless challenge.

pub fn challenge_id(&self) -> &str

Returns the challenge identifier supplied to the proof verifier.

pub fn method(&self) -> PasswordlessMethod

Returns the selected passwordless method.

pub fn device_binding(&self) -> &DeviceSessionBinding

Returns the device-session binding.

pub fn issued_at(&self) -> OffsetDateTime

Returns the challenge issue time.

pub fn expires_at(&self) -> OffsetDateTime

Returns the challenge expiry time.