pub struct BoundUserSession { /* private fields */ }Expand description
User session token bound to the authorised session certificate.
Implementations
Sourceimpl BoundUserSession
impl BoundUserSession
Sourcepub fn new(
session_token: impl Into<String>,
identity: &AuthenticatedIdentity,
binding: DeviceSessionBinding,
created_at: OffsetDateTime,
expires_at: OffsetDateTime,
) -> Self
pub fn new( session_token: impl Into<String>, identity: &AuthenticatedIdentity, binding: DeviceSessionBinding, created_at: OffsetDateTime, expires_at: OffsetDateTime, ) -> Self
Creates a bound user session.
Sourcepub fn session_token(&self) -> &str
pub fn session_token(&self) -> &str
Returns the opaque user session token.
Sourcepub fn device_binding(&self) -> &DeviceSessionBinding
pub fn device_binding(&self) -> &DeviceSessionBinding
Returns the device-session binding.
Sourcepub fn created_at(&self) -> OffsetDateTime
pub fn created_at(&self) -> OffsetDateTime
Returns the session creation time.
Sourcepub fn expires_at(&self) -> OffsetDateTime
pub fn expires_at(&self) -> OffsetDateTime
Returns the session expiry time.
Sourcepub fn is_bound_to(&self, mtls: &MtlsClientIdentity) -> bool
pub fn is_bound_to(&self, mtls: &MtlsClientIdentity) -> bool
Returns true when this session is presented with its original mTLS certificate.