pub struct PasswordlessChallenge { /* private fields */ }Expand description
Passwordless challenge issued after device trust and session mTLS checks.
Implementations
Sourceimpl PasswordlessChallenge
impl PasswordlessChallenge
Sourcepub fn new(
challenge_id: impl Into<String>,
method: PasswordlessMethod,
binding: DeviceSessionBinding,
issued_at: OffsetDateTime,
expires_at: OffsetDateTime,
) -> Self
pub fn new( challenge_id: impl Into<String>, method: PasswordlessMethod, binding: DeviceSessionBinding, issued_at: OffsetDateTime, expires_at: OffsetDateTime, ) -> Self
Creates a passwordless challenge.
Sourcepub fn challenge_id(&self) -> &str
pub fn challenge_id(&self) -> &str
Returns the challenge identifier supplied to the proof verifier.
Sourcepub fn method(&self) -> PasswordlessMethod
pub fn method(&self) -> PasswordlessMethod
Returns the selected passwordless method.
Sourcepub fn device_binding(&self) -> &DeviceSessionBinding
pub fn device_binding(&self) -> &DeviceSessionBinding
Returns the device-session binding.
Sourcepub fn issued_at(&self) -> OffsetDateTime
pub fn issued_at(&self) -> OffsetDateTime
Returns the challenge issue time.
Sourcepub fn expires_at(&self) -> OffsetDateTime
pub fn expires_at(&self) -> OffsetDateTime
Returns the challenge expiry time.